unit Unit2;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, ZConnection, ZDataset;

procedure CreateTable(Connection : TZConnection);
procedure DeleteTable(Connection : TZConnection);
procedure TestAndCreateDB(DBName: string; Connection : TZConnection);


implementation

uses
  LazFileUtils;

procedure CreateTable(Connection: TZConnection);
begin
  Connection.Disconnect;
  Connection.AutoCommit:=true;
  Connection.Connect;
  Connection.StartTransaction;
  Connection.ExecuteDirect('CREATE TABLE [orders] ( ' +
           ' [ord_id] INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,' +
           ' [ord_forid] INTEGER,' +
           ' [ord_datum] TIMESTAMP DEFAULT CURRENT_TIMESTAMP,' +
           ' [ord_firma] VARCHAR(50),' +
           ' [ord_sel_anrede] VARCHAR(10),' +
           ' [ord_vorname] VARCHAR(30),' +
           ' [ord_nachname] VARCHAR(30),' +
           ' [ord_strasse] VARCHAR(30),' +
           ' [ord_plz] VARCHAR(8),' +
           ' [ord_ort] VARCHAR(30),' +
           ' [ord_land] VARCHAR(30),' +
           ' [ord_telefon] VARCHAR(30),' +
           ' [ord_fax] VARCHAR(30),' +
           ' [ord_email] VARCHAR(130),' +
           ' [ord_internet] VARCHAR(50),' +
           ' [ord_lieffirma] VARCHAR(50),' +
           ' [ord_liefsel_anrede] VARCHAR(10),' +
           ' [ord_liefvorname] VARCHAR(30),' +
           ' [ord_liefnachname] VARCHAR(30),' +
           ' [ord_liefstrasse] VARCHAR(30),' +
           ' [ord_liefplz] VARCHAR(8),' +
           ' [ord_liefort] VARCHAR(30),' +
           ' [ord_liefland] VARCHAR(30),' +
           ' [ord_lieftelefon] VARCHAR(30),' +
           ' [ord_lieffax] VARCHAR(30),' +
           ' [ord_liefemail] VARCHAR(130),' +
           ' [ord_liefinternet] VARCHAR(50),' +
           ' [ord_bemerkung1] TEXT,' +
           ' [ord_bemerkung2] TEXT,' +
           ' [ord_bemerkung3] TEXT,' +
           ' [ord_rabatt] FLOAT,' +
           ' [AUFSKONTO] REAL DEFAULT 0,' +
           ' [AUFLIEFVERWENDEN] INTEGER DEFAULT 0,' +
           ' [AUFSTEUER] REAL DEFAULT 0,' +
           ' [AUFSKONTOTAGE] INTEGER DEFAULT 0,' +
           ' [AUFSTEUERVERWENDEN] INTEGER DEFAULT 0,' +
           ' [AUFRABATTBETRAG] REAL DEFAULT 0,' +
           ' [AUFZAHLFRISTEN] CHAR(120),' +
           ' [ord_rabattverwenden] INTEGER,' +
           ' [AUFSKONTOVERWENDEN] INTEGER DEFAULT 0,' +
           ' [ord_versandkosten] FLOAT,' +
           ' [AUFVERSANDART] VARCHAR(20),' +
           ' [ord_bestellung] TEXT,' +
           ' [ord_rechnung] TEXT,' +
           ' [ord_vermerke] TEXT,' +
           ' [ord_gesgewicht] FLOAT DEFAULT 0,' +
           ' [ord_bemerkungen] TEXT,' +
           ' [ord_status] INTEGER,' +
           ' [ord_adresse] TEXT,' +
           ' [ord_liefadresse] TEXT);');

  Connection.ExecuteDirect('CREATE INDEX [orders_datumidx] ON [orders] ([ord_datum]);');
  Connection.Commit;
  Connection.Disconnect;
end;

procedure DeleteTable(Connection: TZConnection);
begin
  Connection.Disconnect;
  Connection.AutoCommit:=true;
  Connection.Connect;
  // Index löschen
  Connection.StartTransaction;
  Connection.ExecuteDirect('DROP INDEX IF EXISTS [orders_datumidx];');
  Connection.Commit;
  // Tabelle löschen
  Connection.StartTransaction;
  Connection.ExecuteDirect('DROP TABLE IF EXISTS [orders];');
  Connection.Commit;
  // Leerräume wieder freigeben
  Connection.StartTransaction;
  Connection.ExecuteDirect('VACUUM;');
  Connection.Commit;
  Connection.Disconnect;
end;

procedure TestAndCreateDB(DBName: string; Connection: TZConnection);
begin
  if Connection.Connected then
    exit; //==> DB bereits aktiv
  Connection.Database:=DBName;
  Connection.Protocol:='sqlite-3';
  Connection.AutoCommit:=true;
  if not FileExistsUTF8(DBName) then
  begin
    // bei SQLite reicht ein öffnen der Verbindung zum Erzeugen einer
    // leeren Datenbank
    Connection.Connected:=true;
    Connection.Connected:=false;
  end;
end;


end.

